# Changelog

All notable changes to this project will be documented in this file.

The format is based on [Keep a Changelog](https://keepachangelog.com/en/1.0.0/),
and this project adheres to [Semantic Versioning](https://semver.org/spec/v2.0.0.html).

## 24.0.0.dev0 - 2024-01-23

### Added

- `haltia.sdk.licensee()`
- `haltia.sdk.version()`
